make_full_perm_set: make_full_perm_set

View source: R/make_full_perm_set.R

make_full_perm_setR Documentation

make_full_perm_set

Description

Given a length n, make_full_perm_set finds all permutations of length n whose elements can be 0 or 1.

Usage

make_full_perm_set(length)

Arguments

length

The length of each permutation.

Value

Returns a matrix with n columns, where each row corresponds to a different permutation of 0s and 1s.

Examples

# All possible permutations of length 3
make_full_perm_set(3)

hrj21/nonogram documentation built on April 6, 2024, 1:14 a.m.