View source: R/plot.nonogram.R
| plot.nonogram | R Documentation |
Method for plotting solved and unsolved nonograms using the ggplot2 and patchwork packages.
## S3 method for class 'nonogram'
plot(nonogram, with_solution = TRUE)
nonogram |
An object of class nonogram. |
with_solution |
with_solution |
If with_solution = FALSE, the function will plot an empty nonogram
with the row and column patterns indicated. If with_solution = TRUE and
the nonogram does not have a solution, the function will throw an error.
An object of classes patchwork, gg, and ggplot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.